@@ -5,7 +5,10 @@ TestEvent = Enum(
     "TestEvent",
     """
     artifact_created
+    http_request_sent
+    http_response_received
     report_created
+    sample_measured
     suite_ended
     suite_erred
     suite_results_compiled
